io package
==========


.. toctree::
   :caption: io package
   :maxdepth: 1
   :hidden:

   io/file
   io/pdbfile
   io/functions

- :doc:`file module <io/file>`
- :doc:`pdbfile module <io/pdbfile>`
- :doc:`functions <io/functions>`
